@@ -22,10 +22,11 @@ import time
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, Sequence, Union
 
 from airflow.exceptions import AirflowException
-from airflow.models import BaseOperator
+from airflow.models import BaseOperator, BaseOperatorLink, XCom
 from airflow.providers.databricks.hooks.databricks import DatabricksHook
 
 if TYPE_CHECKING:
+    from airflow.models.taskinstance import TaskInstanceKey
     from airflow.utils.context import Context
 
 XCOM_RUN_ID_KEY = 'run_id'
@@ -70,11 +71,11 @@ def _handle_databricks_operator_execution(operator, hook, log, context) -> None:
     :param operator: Databricks operator being handled
     :param context: Airflow context
     """
-    if operator.do_xcom_push:
+    if operator.do_xcom_push and context is not None:
         context['ti'].xcom_push(key=XCOM_RUN_ID_KEY, value=operator.run_id)
     log.info('Run submitted with run_id: %s', operator.run_id)
     run_page_url = hook.get_run_page_url(operator.run_id)
-    if operator.do_xcom_push:
+    if operator.do_xcom_push and context is not None:
         context['ti'].xcom_push(key=XCOM_RUN_PAGE_URL_KEY, value=run_page_url)
 
     if operator.wait_for_termination:
@@ -102,6 +103,32 @@ def _handle_databricks_operator_execution(operator, hook, log, context) -> None:
         log.info('View run status, Spark UI, and logs at %s', run_page_url)
 
 
+class DatabricksJobRunLink(BaseOperatorLink):
+    """Constructs a link to monitor a Databricks Job Run."""
+
+    name = "See Databricks Job Run"
+
+    def get_link(
+        self,
+        operator,
+        dttm=None,
+        *,
+        ti_key: Optional["TaskInstanceKey"] = None,
+    ) -> str:
+        if ti_key is not None:
+            run_page_url = XCom.get_value(key=XCOM_RUN_PAGE_URL_KEY, ti_key=ti_key)
+        else:
+            assert dttm
+            run_page_url = XCom.get_one(
+                key=XCOM_RUN_PAGE_URL_KEY,
+                dag_id=operator.dag.dag_id,
+                task_id=operator.task_id,
+                execution_date=dttm,
+            )
+
+        return run_page_url
+
+
 class DatabricksSubmitRunOperator(BaseOperator):
     """
     Submits a Spark job run to Databricks using the
@@ -255,6 +282,7 @@ class DatabricksSubmitRunOperator(BaseOperator):
     # Databricks brand color (blue) under white text
     ui_color = '#1CB1C2'
     ui_fgcolor = '#fff'
+    operator_extra_links = (DatabricksJobRunLink(),)
 
     def __init__(
         self,
@@ -276,7 +304,7 @@ class DatabricksSubmitRunOperator(BaseOperator):
         databricks_retry_limit: int = 3,
         databricks_retry_delay: int = 1,
         databricks_retry_args: Optional[Dict[Any, Any]] = None,
-        do_xcom_push: bool = False,
+        do_xcom_push: bool = True,
         idempotency_token: Optional[str] = None,
         access_control_list: Optional[List[Dict[str, str]]] = None,
         wait_for_termination: bool = True,
@@ -498,6 +526,7 @@ class DatabricksRunNowOperator(BaseOperator):
     # Databricks brand color (blue) under white text
     ui_color = '#1CB1C2'
     ui_fgcolor = '#fff'
+    operator_extra_links = (DatabricksJobRunLink(),)
 
     def __init__(
         self,
@@ -514,7 +543,7 @@ class DatabricksRunNowOperator(BaseOperator):
         databricks_retry_limit: int = 3,
         databricks_retry_delay: int = 1,
         databricks_retry_args: Optional[Dict[Any, Any]] = None,
-        do_xcom_push: bool = False,
+        do_xcom_push: bool = True,
         wait_for_termination: bool = True,
         **kwargs,
     ) -> None:
